pub enum SwapInterval {
None,
Adaptive,
Sync(u32),
}Expand description
Specifies how the context should handle swapping the buffers.
i.e. the number of screen updates to wait from the time
glfwSwapBuffers/context.swap_buffers
was called before swapping the buffers and returning.
Variants
None
Specifies no waits
Adaptive
If either of the WGL_EXT_swap_control_tear and GLX_EXT_swap_control_tear extensions
are enabled, allows the adaptively swap the frame. Sometimes called Adaptive V-sync
Sync(u32)
Synchronizes the buffers every N frames. Set to 1 for V-sync